CVAgsvd: CVA using the GSVD

View source: R/CVAgsvd.R

CVAgsvdR Documentation

CVA using the GSVD

Description

Compute canonical variate analysis using the generalised singular value decomposition when number of variables (p) is larger than the number of samples (n).

Usage

CVAgsvd(X, group)

Arguments

X

n x p data matrix

group

vector of size n showing the groups

Details

If p < n, then the solution defaults to the standard canonical variate analysis.

Value

An object with components of a CVA biplot

Examples

CVAgsvd(X=iris[,1:4],group = iris[,5]) |>
CVAbiplot(group.col = c("orange","red","pink"))

wideRhino documentation built on July 2, 2026, 5:07 p.m.