| CVAgsvd | R Documentation |
Compute canonical variate analysis using the generalised singular value decomposition when number of variables (p) is larger than the number of samples (n).
CVAgsvd(X, group)
X |
n x p data matrix |
group |
vector of size n showing the groups |
If p < n, then the solution defaults to the standard canonical variate analysis.
An object with components of a CVA biplot
CVAgsvd(X=iris[,1:4],group = iris[,5]) |>
CVAbiplot(group.col = c("orange","red","pink"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.