Learn R Programming

wideRhino (version 1.0.2)

CVAgsvd: CVA Biplot using the GSVD

Description

Create a CVA biplot using the generalised singular value decomposition when number of variables (p) is larger than the number of samples (n).

Usage

CVAgsvd(X, group)

Value

An object with components of a CVA biplot

Arguments

X

n x p data matrix

group

vector of size n showing the groups

Details

If p < n, then the solution defaults to the standard CVA biplot.

Examples

Run this code
CVAgsvd(X=iris[,1:4],group = iris[,5]) |>
CVAbiplot(group.col = c("orange","red","pink"))

Run the code above in your browser using DataLab