powered by
Create a CVA biplot using the generalised singular value decomposition when number of variables (p) is larger than the number of samples (n).
CVAgsvd(X, group)
An object with components of a CVA biplot
n x p data matrix
vector of size n showing the groups
If p < n, then the solution defaults to the standard CVA biplot.
CVAgsvd(X=iris[,1:4],group = iris[,5]) |> CVAbiplot(group.col = c("orange","red","pink"))
Run the code above in your browser using DataLab